netapp_ontap.models.snapmirror_destination_creation API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_destination_creation`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorDestinationCreationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorDestinationCreation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled POST`

    Optional property to create the destination endpoint when establishing a SnapMirror relationship. It is assumed to be "false" if no other property is set and assumed to be "true" if any other property is set.

  `storage_service POST`

    The storage_service field of the snapmirror_destination_creation.

  `tiering POST`

    The tiering field of the snapmirror_destination_creation.